import model
import santa

def about():
	santa.title('MALLU','*')
	print()
	santa.title('ABOUT THE AUTHOR','=')
	santa.title('MALLU module is written by Santo K Thomas, Kerala, India')
	santa.title('Email:santokalayil@gmail.com')
	santa.title('-')
	print()
	santa.title('HOW TO USE THE MODULE','=')
	santa.title('import mallu.santa as mls',' ')
	santa.title('import mallu.model as mlm',' ')

